@@ -19,7 +19,6 @@ void __bzero(void *, size_t);
 void *memcpy(void *, const void *, size_t);
 void *memmove(void *, const void *, size_t);
 
-/* stringops2.c */
 char *strcat(char *, const char *);
 char *strncat(char *, const char *, size_t);
 int strncmp(const char *, const char *, size_t);
@@ -31,8 +30,6 @@ char *strdup(const char *);
 int strcasecmp(const char *, const char *);
 int strncasecmp(const char *, const char *, size_t);
 char *strstr(const char *, const char *);
-void *realloc(void *, int);
 int memcmp(const void *, const void *, size_t);
-int sprintf (char *, char *, ...);
 
 #endif /* __STRINGOPS_H */
